@@ -9,7 +9,7 @@ import pygame
 import designer
 import math
 
-from colors import _process_color
+from designer.colors import _process_color
 
 
 class DesignerObject(pygame.sprite.DirtySprite):
@@ -77,7 +77,6 @@ class Circle(DesignerObject):
 
         self.rect = self.image.get_rect(center=center)
 
-
         super().add()
 
 
@@ -111,25 +110,6 @@ class Ellipse(DesignerObject):
         super().add()
 
 
-def ellipse(color, args):
-    '''
-    Function to make ellipse.
-
-    :param color: color of ellipse
-    :type color: str or List[str]
-    :param args: left top corner of ellipse and width and height of ellipse
-    :type args: two Tuples (left, top), (width, height) or four ints left, top, width, height
-    :return: Ellipse object created
-    '''
-    if len(args) > 2:
-        left, top = args[0], args[1]
-        width, height = args[2], args[3]
-    else:
-        left, top = args[0]
-        width, height = args[1]
-    return Ellipse(color, left, top, width, height)
-
-
 class Arc(DesignerObject):
     def __init__(self, color, start_angle, stop_angle, thickness, left, top, width, height):
         """
@@ -166,31 +146,6 @@ class Arc(DesignerObject):
         super().add()
 
 
-def arc(color, start_angle, stop_angle, thickness, args):
-    """
-    Function to make arc.
-
-    :param color: color to draw arc
-    :type color: str or List[str]
-    :param start_angle: angle to start drawing arc at
-    :type start_angle: int
-    :param stop_angle: angle to stop drawing arc at
-    :type stop_angle: int
-    :param thickness: thickness of arc in pixels
-    :type thickness: int
-    :param args: left top corner of arc and width and height of arc
-    :type args: two Tuples (left, top), (width, height) or four ints left, top, width, height
-    :return: Arc object created
-    """
-    if len(args) > 2:
-        left, top = args[0], args[1]
-        width, height = args[2], args[3]
-    else:
-        left, top = args[0]
-        width, height = args[1]
-    return Arc(color, start_angle, stop_angle, thickness, left, top, width, height)
-
-
 class Line(DesignerObject):
     def __init__(self, start, end, thickness, color):
         """
@@ -266,8 +221,6 @@ class Rectangle(DesignerObject):
         self.image = pygame.surface.Surface((width, height), pygame.SRCALPHA, 32).convert_alpha()
         pygame.draw.rect(self.image, color, (0, 0, width, height))
 
-
-
         self.color = color
         self.rect = self.image.get_rect()
         self.rect.topleft = (left, top)
@@ -275,25 +228,6 @@ class Rectangle(DesignerObject):
         super().add()
 
 
-def rectangle(color, *args):
-    '''
-    Function to create a rectangle.
-
-    :param color: color of rectangle
-    :type color: str or List[str]
-    :param args: left top corner of image and width and height of rectangle
-    :type args: two Tuples (left, top), (width, height) or four ints left, top, width, height
-    :return: Rectangle object
-    '''
-    if len(args) > 2:
-        left, top = args[0], args[1]
-        width, height = args[2], args[3]
-    else:
-        left, top = args[0]
-        width, height = args[1]
-    return Rectangle(left, top, width, height, color)
-
-
 class Text(DesignerObject):
     def __init__(self, left, top, text_color, text, text_size):
         """
@@ -343,30 +277,6 @@ class Shape(DesignerObject):
         super().add()
 
 
-def shape(color, points: List[Tuple]):
-    designer.check_initialized()
-    max_x = 0
-    max_y = 0
-    new_points = []
-    min_x = designer.GLOBAL_DIRECTOR.width
-    min_y = designer.GLOBAL_DIRECTOR.height
-    for pt in points:
-        if pt[0] < min_x:
-            min_x = pt[0]
-        if pt[0] > max_x:
-            max_x = pt[0]
-        if pt[1] < min_y:
-            min_y = pt[1]
-        if pt[1] > max_y:
-            max_y = pt[1]
-        x = designer.GLOBAL_DIRECTOR.width - pt[0]
-        y = designer.GLOBAL_DIRECTOR.height - pt[1]
-        new_points.append((x, y))
-    width = max_x - min_x
-    height = max_y - min_y
-    new_points = [(x - min_x, y - min_y) for x, y in points]
-    return Shape(new_points, min_x, min_y, width, height, color)
-
 
 class Image(DesignerObject):
     def __init__(self, path, left, top, width, height):
@@ -422,7 +332,7 @@ def circle(color, radius, *args):
     :param color: color of circle
     :param radius: int, radius of circle in pixels
     :param args: center of circle in x, y either as separate ints or as a tuple of ints
-    :return: Circle object
+    :return: Circle object created
     '''
     if len(args) >= 2:
         x, y = args[0], args[1]
@@ -431,7 +341,51 @@ def circle(color, radius, *args):
     return Circle((x, y), radius, color)
 
 
-def line(thickness, color, *args):
+def ellipse(color, args):
+    '''
+    Function to make an ellipse.
+
+    :param color: color of ellipse
+    :type color: str or List[str]
+    :param args: left top corner of ellipse and width and height of ellipse
+    :type args: two Tuples (left, top), (width, height) or four ints left, top, width, height
+    :return: Ellipse object created
+    '''
+    if len(args) > 2:
+        left, top = args[0], args[1]
+        width, height = args[2], args[3]
+    else:
+        left, top = args[0]
+        width, height = args[1]
+    return Ellipse(color, left, top, width, height)
+
+
+def arc(color, start_angle, stop_angle, thickness, *args):
+    """
+    Function to make an arc.
+
+    :param color: color to draw arc
+    :type color: str or List[str]
+    :param start_angle: angle to start drawing arc at
+    :type start_angle: int
+    :param stop_angle: angle to stop drawing arc at
+    :type stop_angle: int
+    :param thickness: thickness of arc in pixels
+    :type thickness: int
+    :param args: left top corner of arc and width and height of arc
+    :type args: two Tuples (left, top), (width, height) or four ints left, top, width, height
+    :return: Arc object created
+    """
+    if len(args) > 2:
+        left, top = args[0], args[1]
+        width, height = args[2], args[3]
+    else:
+        left, top = args[0]
+        width, height = args[1]
+    return Arc(color, start_angle, stop_angle, thickness, left, top, width, height)
+
+
+def line(color, thickness, *args):
     '''
     Function to create a line.
 
@@ -453,7 +407,37 @@ def line(thickness, color, *args):
     return Line(start, end, thickness, color)
 
 
+def rectangle(color, *args):
+    '''
+    Function to create a rectangle.
+
+    :param color: color of rectangle
+    :type color: str or List[str]
+    :param args: left top corner of image and width and height of rectangle
+    :type args: two Tuples (left, top), (width, height) or four ints left, top, width, height
+    :return: Rectangle object created
+    '''
+    if len(args) > 2:
+        left, top = args[0], args[1]
+        width, height = args[2], args[3]
+    else:
+        left, top = args[0]
+        width, height = args[1]
+    return Rectangle(left, top, width, height, color)
+
+
 def text(text_color, text, text_size, *args):
+    '''
+       Function to create text.
+
+       :param color: color of text
+       :type color: str or List[str]
+       :param text: text to appear on window
+       :type text: str
+       :param args: top left coordinates of text box
+       :type args: either Tuple (left, top) or two ints (left, top)
+       :return: Text object created
+       '''
     if len(args) >= 2:
         left, top = args[0], args[1]
     else:
@@ -461,6 +445,40 @@ def text(text_color, text, text_size, *args):
     return Text(left, top, text_color, text, text_size)
 
 
+def shape(color, points: List[Tuple]):
+    '''
+           Function to create a shape of at least three points.
+
+           :param color: color of shape.
+           :type color: str or List[str]
+           :param points: coordinates of points of shape
+           :type points: List[Tuple] in (x, y), (x, y) format of points to be connected of shape
+           :return: Shape object created
+           '''
+    designer.check_initialized()
+    max_x = 0
+    max_y = 0
+    new_points = []
+    min_x = designer.GLOBAL_DIRECTOR.width
+    min_y = designer.GLOBAL_DIRECTOR.height
+    for pt in points:
+        if pt[0] < min_x:
+            min_x = pt[0]
+        if pt[0] > max_x:
+            max_x = pt[0]
+        if pt[1] < min_y:
+            min_y = pt[1]
+        if pt[1] > max_y:
+            max_y = pt[1]
+        x = designer.GLOBAL_DIRECTOR.width - pt[0]
+        y = designer.GLOBAL_DIRECTOR.height - pt[1]
+        new_points.append((x, y))
+    width = max_x - min_x
+    height = max_y - min_y
+    new_points = [(x - min_x, y - min_y) for x, y in points]
+    return Shape(new_points, min_x, min_y, width, height, color)
+
+
 def image(path, *args):
     '''
     Function to create an image.
